

.. _`CIM objects`:

CIM objects
-----------

.. index:: pair: CIM Objects; libraries

.. automodule:: pywbem._cim_obj

.. _`NocaseDict`:

NocaseDict
^^^^^^^^^^

.. automodule:: pywbem._nocasedict

.. autoclass:: pywbem.NocaseDict
    :members:
    :special-members:
    :exclude-members: __init__,__weakref__

CIMInstanceName
^^^^^^^^^^^^^^^

.. autoclass:: pywbem.CIMInstanceName
    :members:
    :special-members:
    :exclude-members: __init__,__weakref__
    :autosummary:
    :autosummary-inherited-members:

CIMInstance
^^^^^^^^^^^

.. autoclass:: pywbem.CIMInstance
    :members:
    :special-members:
    :exclude-members: __init__,__weakref__
    :autosummary:
    :autosummary-inherited-members:

CIMClassName
^^^^^^^^^^^^

.. autoclass:: pywbem.CIMClassName
    :members:
    :special-members:
    :exclude-members: __init__,__weakref__
    :autosummary:
    :autosummary-inherited-members:

CIMClass
^^^^^^^^

.. autoclass:: pywbem.CIMClass
    :members:
    :special-members:
    :exclude-members: __init__,__weakref__
    :autosummary:
    :autosummary-inherited-members:

CIMProperty
^^^^^^^^^^^

.. autoclass:: pywbem.CIMProperty
    :members:
    :special-members:
    :exclude-members: __init__,__weakref__
    :autosummary:
    :autosummary-inherited-members:

CIMMethod
^^^^^^^^^

.. autoclass:: pywbem.CIMMethod
    :members:
    :special-members:
    :exclude-members: __init__,__weakref__
    :autosummary:
    :autosummary-inherited-members:

CIMParameter
^^^^^^^^^^^^

.. autoclass:: pywbem.CIMParameter
    :members:
    :special-members:
    :exclude-members: __init__,__weakref__
    :autosummary:
    :autosummary-inherited-members:

CIMQualifier
^^^^^^^^^^^^

.. autoclass:: pywbem.CIMQualifier
    :members:
    :special-members:
    :exclude-members: __init__,__weakref__
    :autosummary:
    :autosummary-inherited-members:

CIMQualifierDeclaration
^^^^^^^^^^^^^^^^^^^^^^^

.. autoclass:: pywbem.CIMQualifierDeclaration
    :members:
    :special-members:
    :exclude-members: __init__,__weakref__
    :autosummary:
    :autosummary-inherited-members:
